/*
 * Copyright 2006-2018 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.objenesis.tck.features;

import java.io.Externalizable;
import java.io.ObjectInput;
import java.io.ObjectOutput;
import java.io.Serializable;

import org.objenesis.Objenesis;

/**
 * {@code Externalizable} methods should not be called during instantiation.
 *
 * @author Henri Tremblay
 */
public class ReadExternalNotCalled extends AbstractFeature {

   public static class ReadExternalAndAll implements Serializable, Externalizable {
      @Override
      public void writeExternal(ObjectOutput out) {
         called.add("writeExternal");
      }

      @Override
      public void readExternal(ObjectInput in) {
         called.add("readExternal");
      }
   }

   @Override
   public boolean isCompliant(Objenesis objenesis) {
      objenesis.newInstance(ReadExternalAndAll.class);
      return called.isEmpty();
   }
}
